@@ -1,9 +1,9 @@
 import numpy as np
-from deeptile import utils
-from deeptile.algorithms import AlgorithmBase
-from deeptile.data import Tiled, Stitched
-from deeptile.jobs import Job
-from deeptile.profiles import Profile
+from deeptile.core import utils
+from deeptile.core.algorithms import AlgorithmBase
+from deeptile.core.data import Tiled, Stitched
+from deeptile.core.jobs import Job
+from deeptile.core.profiles import Profile
 
 
 class DeepTile:
@@ -24,7 +24,7 @@ class DeepTile:
         self.link_data = None
         self.profiles = []
 
-    def process(self, tiles, func_process, batch_axis=None, batch_size=None, pad_final_batch=False):
+    def process(self, tiles, func_process, batch_axis=False, batch_size=None, pad_final_batch=False):
 
         """ Process tiles using a transformed function.
 
@@ -34,14 +34,14 @@ class DeepTile:
                 Array of tiles.
             func_process : Algorithm
                 Processing function transformed into an Algorithm object.
-            batch_axis : int or None, optional, default None
-                Image axis used to create batches during processing. If ``None``, no batch axis will be used.
+            batch_axis : bool, optional, default False
+                Whether to use the first axis to create batches. If ``None``, no batch axis will be used.
             batch_size : int or None, optional, default None
                 Number of tiles in each batch. If ``None``, the default batching configuration will be determined by
-                ``func_process``. If ``func_process`` is not vectorized, this value is ignored.
+                ``func_process``. If ``func_process`` does not support batching, this value is ignored.
             pad_final_batch : bool, optional, default False
-                Whether to pad the final batch to the specified ``batch_size``. If ``func_process`` is not vectorized,
-                this value is ignored.
+                Whether to pad the final batch to the specified ``batch_size``. If ``func_process`` does not support
+                batching, this value is ignored.
 
         Returns
         -------
@@ -57,21 +57,22 @@ class DeepTile:
         self._check_compatibility(tiles, func_process, 'process')
 
         job = Job(tiles, 'process', job_kwargs)
-
         profile = job.profile
+
+        unpack_input_singleton = isinstance(func_process.input_type, str)
+        unpack_output_singleton = isinstance(func_process.output_type, str)
+        output_type = utils.to_tuple(func_process.output_type)
+
         nonempty_indices = profile.nonempty_indices
         nonempty_tiles = [ts.nonempty_tiles for ts in tiles]
-
-        output_type = utils.to_tuple(func_process.output_type)
         processed_tiles = [np.empty(profile.tiling, dtype=object) for _ in range(len(output_type))]
 
-        if batch_axis is not None:
-            batch_axis_len = nonempty_tiles[0][0].shape[batch_axis]
+        if batch_axis:
+            batch_axis_len = nonempty_tiles[0][0].shape[0]
             nonempty_indices = np.repeat(np.array(nonempty_indices), batch_axis_len, 0)
-            nonempty_tiles = [[subt for t in ts for subt in list(np.moveaxis(t, batch_axis, 0))]
-                              for ts in nonempty_tiles]
+            nonempty_tiles = [[subt for t in ts for subt in t] for ts in nonempty_tiles]
 
-        if func_process.vectorized:
+        if func_process.batching:
 
             if batch_size is None:
                 batch_size = func_process.default_batch_size
@@ -82,16 +83,19 @@ class DeepTile:
 
                 batch_indices = nonempty_indices[n * batch_size:(n + 1) * batch_size]
                 batch_tiles = [np.stack(ts[n * batch_size:(n + 1) * batch_size]) for ts in nonempty_tiles]
-                if pad_final_batch & (batch_tiles[0].shape[0] < batch_size):
+                if pad_final_batch and (batch_tiles[0].shape[0] < batch_size):
                     batch_tiles = [utils.array_pad(ts, batch_size - ts.shape[0], 0) for ts in batch_tiles]
                 batch_tiles = utils.compute_dask(batch_tiles)
+                if unpack_input_singleton:
+                    batch_tiles = batch_tiles[0]
 
-                processed_batch_tiles = func_process(*batch_tiles)
+                processed_batch_tiles = func_process(tiles=batch_tiles)
                 processed_batch_tiles = utils.to_tuple(processed_batch_tiles)
 
                 for i_batch, index in enumerate(batch_indices):
 
                     processed_tile = tuple(ts[i_batch] for ts in processed_batch_tiles)
+                    utils.check_data_count(processed_tile, output_type=output_type)
                     processed_tiles = utils.update_tiles(processed_tiles, tuple(index), processed_tile, batch_axis,
                                                          output_type)
 
@@ -101,15 +105,18 @@ class DeepTile:
 
                 tile = [ts[i_nonempty] for ts in nonempty_tiles]
                 tile = utils.compute_dask(tile)
+                if unpack_input_singleton:
+                    tile = tile[0]
 
-                processed_tile = func_process(*tile)
+                processed_tile = func_process(tile=tile)
                 processed_tile = utils.to_tuple(processed_tile)
+                utils.check_data_count(processed_tile, output_type=output_type)
                 processed_tiles = utils.update_tiles(processed_tiles, tuple(index), processed_tile, batch_axis,
                                                      output_type)
 
         processed_tiles = [Tiled(ts, job, otype) for ts, otype in zip(processed_tiles, output_type)]
 
-        if len(processed_tiles) == 1:
+        if unpack_output_singleton:
             processed_tiles = processed_tiles[0]
         else:
             processed_tiles = tuple(processed_tiles)
@@ -142,8 +149,22 @@ class DeepTile:
 
         job = Job(tiles, 'stitch', job_kwargs)
 
-        stitched = func_stitch(*tiles)
-        stitched = Stitched(stitched, job, func_stitch.output_type)
+        unpack_input_singleton = isinstance(func_stitch.input_type, str)
+        unpack_output_singleton = isinstance(func_stitch.output_type, str)
+        output_type = utils.to_tuple(func_stitch.output_type)
+
+        if unpack_input_singleton:
+            tiles = tiles[0]
+
+        stitched = func_stitch(tiles=tiles)
+        stitched = utils.to_tuple(stitched)
+        utils.check_data_count(stitched, output_type=output_type)
+        stitched = [Stitched(s, job, otype) for s, otype in zip(stitched, output_type)]
+
+        if unpack_output_singleton:
+            stitched = stitched[0]
+        else:
+            stitched = tuple(stitched)
 
         return stitched
 
@@ -162,46 +183,40 @@ class DeepTile:
 
         Raises
         ------
-            ValueError
-                If ``tiles`` has an input count that does not match the expected ``func`` input count.
+            TypeError
+                If ``func`` has not been transformed to an instance of the Algorithm class.
+            TypeError
+                If ``func`` has the incorrect algorithm type.
             ValueError
                 If ``tiles`` has an object type that does not match the expected ``func`` input object type.
             ValueError
                 If ``tiles`` are not associated with this DeepTile object.
             ValueError
                 If ``tiles`` do not all share a common profile.
-            TypeError
-                If ``func`` has not been transformed to an instance of the Algorithm class.
-            TypeError
-                If ``func`` has the incorrect algorithm type.
         """
 
-        input_type = utils.to_tuple(func.input_type)
-        num_expected = len(input_type)
-        num_got = len(tiles)
-
-        if num_expected != num_got:
-            raise ValueError(f'Expected input count {num_expected}, got {num_got}.')
-
-        profile = None
-        for i, ts in enumerate(tiles):
-            if ts.otype != input_type[i]:
-                raise ValueError(f"Tile object type does not match the expected function input object type.")
-            if profile is None:
-                if ts.dt is self:
-                    profile = ts.profile
-                else:
-                    raise ValueError("Tiles are not associated with this DeepTile object.")
-            else:
-                if ts.profile is not profile:
-                    raise ValueError(f'Tiles must all share a common profile.')
-
         if not issubclass(type(func), AlgorithmBase):
             raise TypeError(f"func_{job_type} must be transformed to an instance of the Algorithm class.")
 
         if func.algorithm_type != job_type:
             raise TypeError(f"func_{job_type} has the incorrect algorithm type of {func.algorithm_type}.")
 
+        input_type = utils.to_tuple(func.input_type)
+        utils.check_data_count(tiles, input_type=input_type)
+
+        profile = None
+        for i, ts in enumerate(tiles):
+            if ts.otype != input_type[i]:
+                raise ValueError(f"tile object type does not match the expected function input object type.")
+            if profile is None:
+                if ts.dt is self:
+                    profile = ts.profile
+                else:
+                    raise ValueError("tiles are not associated with this DeepTile object.")
+            else:
+                if ts.profile is not profile:
+                    raise ValueError(f'tiles must all share a common profile.')
+
 
 class DeepTileArray(DeepTile):
 
