@@ -1,5 +1,5 @@
 import numpy as np
-from deeptile.algorithms import transform
+from deeptile.core.algorithms import transform
 
 
 def cellpose_segmentation(model_parameters, eval_parameters):
@@ -25,14 +25,13 @@ def cellpose_segmentation(model_parameters, eval_parameters):
 
     model = Cellpose(**model_parameters)
 
+    @transform
     def func_segment(tile):
 
         mask = model.eval(tile, tile=False, **eval_parameters)[0]
 
         return mask
 
-    func_segment = transform(func_segment, vectorized=False)
-
     return func_segment
 
 
@@ -57,15 +56,14 @@ def deepcell_mesmer_segmentation(model_parameters, eval_parameters):
 
     model = Mesmer(**model_parameters)
 
-    def func_segment(tile):
+    @transform
+    def func_segment(tiles):
 
-        tile = np.moveaxis(tile, 1, -1)
-        mask = model.predict(tile, batch_size=tile.shape[0], **eval_parameters)
-        mask = np.moveaxis(mask, -1, 1)
+        tiles = np.moveaxis(tiles, 1, -1)
+        masks = model.predict(tiles, batch_size=tiles.shape[0], **eval_parameters)
+        masks = np.moveaxis(masks, -1, 1)
 
-        return mask
-
-    func_segment = transform(func_segment, vectorized=True)
+        return masks
 
     return func_segment
 
@@ -91,14 +89,13 @@ def deepcell_nuclear_segmentation(model_parameters, eval_parameters):
 
     model = NuclearSegmentation(**model_parameters)
 
-    def func_segment(tile):
+    @transform
+    def func_segment(tiles):
 
-        tile = np.expand_dims(tile, axis=-1)
-        mask = model.predict(tile, batch_size=tile.shape[0], **eval_parameters)[:, :, :, 0]
+        tiles = np.expand_dims(tiles, axis=-1)
+        masks = model.predict(tiles, batch_size=tiles.shape[0], **eval_parameters)[:, :, :, 0]
 
-        return mask
-
-    func_segment = transform(func_segment, vectorized=True)
+        return masks
 
     return func_segment
 
@@ -124,13 +121,12 @@ def deepcell_cytoplasm_segmentation(model_parameters, eval_parameters):
 
     model = CytoplasmSegmentation(**model_parameters)
 
-    def func_segment(tile):
+    @transform
+    def func_segment(tiles):
 
-        tile = np.expand_dims(tile, axis=-1)
-        mask = model.predict(tile, batch_size=tile.shape[0], **eval_parameters)[:, :, :, 0]
+        tiles = np.expand_dims(tiles, axis=-1)
+        masks = model.predict(tiles, batch_size=tiles.shape[0], **eval_parameters)[:, :, :, 0]
 
-        return mask
-
-    func_segment = transform(func_segment, vectorized=True)
+        return masks
 
     return func_segment
