@@ -1,7 +1,7 @@
 import numpy as np
 
-from deeptile import utils
-from deeptile.algorithms import transform
+from deeptile.core import utils
+from deeptile.core.algorithms import partial, transform
 from skimage import measure
 
 
@@ -23,6 +23,7 @@ def stitch_tiles(blend=True, sigma=5):
             Algorithm object with a tile stitching algorithm as the callable.
     """
 
+    @partial(transform, output_type='stitched_image')
     def func_stitch(tiles):
 
         profile = tiles.profile
@@ -70,8 +71,6 @@ def stitch_tiles(blend=True, sigma=5):
 
         return stitched
 
-    func_stitch = transform(func_stitch, vectorized=False, output_type='stitched_image')
-
     return func_stitch
 
 
@@ -90,7 +89,10 @@ def stitch_masks(iou_threshold=0.1):
             Algorithm object with a mask stitching algorithm as the callable.
     """
 
-    def func_stitch(masks):
+    @partial(transform, output_type='stitched_image')
+    def func_stitch(tiles):
+
+        masks = tiles
 
         masks = utils.unpad_tiles(masks)
 
@@ -161,8 +163,6 @@ def stitch_masks(iou_threshold=0.1):
 
         return stitched_mask
 
-    func_stitch = transform(func_stitch, vectorized=False, output_type='stitched_image')
-
     return func_stitch
 
 
@@ -176,14 +176,24 @@ def stitch_coords():
             Algorithm object with a coordinate stitching algorithm as the callable.
     """
 
-    def func_stitch(coords):
+    @partial(transform, input_type='tiled_coords', output_type='stitched_coords')
+    def func_stitch(tiles):
+
+        coords = tiles
 
         profile = coords.profile
         nonempty_indices = profile.nonempty_indices
         tile_indices_iterator = coords.tile_indices_iterator
         border_indices_iterator = coords.border_indices_iterator
         first_coord = coords[nonempty_indices[0]]
-        n_batches = first_coord.shape[0]
+
+        if coords.nonempty_tiles[0].dtype is np.dtype('O'):
+            batch_axis = True
+            n_batches = first_coord.shape[0]
+        else:
+            batch_axis = False
+            n_batches = 1
+
         stitched_coords = np.empty(n_batches, dtype=object)
 
         for n in range(n_batches):
@@ -195,7 +205,11 @@ def stitch_coords():
                 tile_index = tile_indices_iterator[index]
                 border_index = border_indices_iterator[index]
 
-                coord = coords[index][n]
+                if batch_axis:
+                    coord = coords[index][n]
+                else:
+                    coord = coords[index]
+
                 coord = coord + np.array([tile_index[0, 0], tile_index[1, 0]])
                 s = (border_index[0, 0] < coord[:, 0]) & (coord[:, 0] < border_index[0, 1]) & \
                     (border_index[1, 0] < coord[:, 1]) & (coord[:, 1] < border_index[1, 1])
@@ -203,9 +217,10 @@ def stitch_coords():
 
             stitched_coords[n] = np.concatenate(batch_coords, axis=0)
 
-        return stitched_coords
+        if not batch_axis:
+            stitched_coords = stitched_coords[0]
 
-    func_stitch = transform(func_stitch, vectorized=False, input_type='tiled_coords', output_type='stitched_coords')
+        return stitched_coords
 
     return func_stitch
 
